ControlRegion

Struct ControlRegion 

pub struct ControlRegion {
    pub data: ControlRegionData,
    /* private fields */
}

Fields

data: ControlRegionData

Implementations

Source

impl ControlRegion

pub unsafe fn init(this: *mut Self)

Initialize a new control region with default values

Safety

This function uses std::ptr::write to initialize the structure. The caller must ensure:

  • this points to properly allocated and aligned memory
  • The memory is writable and not accessed by other threads during initialization
  • This is called only once before any other access
pub fn backpressure(&self) -> f32

pub fn set_backpressure(&self, value: f32)

pub fn increment_client_count(&self) -> u32

pub fn decrement_client_count(&self) -> u32

pub fn set_daemon_alive(&self, alive: bool)

pub fn is_daemon_alive(&self) -> bool

pub fn client_count(&self) -> u32

pub fn version(&self) -> u16

pub fn client_head(&self) -> u64

pub fn set_client_head(&self, pos: u64)

pub fn daemon_tail(&self) -> u64

pub fn set_daemon_tail(&self, pos: u64)

pub fn client_seq(&self) -> u64

pub fn increment_client_seq(&self) -> u64

pub fn daemon_seq(&self) -> u64

pub fn increment_daemon_seq(&self) -> u64

pub fn client_futex(&self) -> u32

pub fn set_client_futex(&self, val: u32)

pub fn daemon_futex(&self) -> u32

pub fn set_daemon_futex(&self, val: u32)